clear, clc;
bo = 1.8276*10^7;
w=2*pi*3.175*10^2;
c=bo/w^2;
zeta=0;

%make the state space matrices
A=[0 1;-(w)^2 0;]; 
B=[0; bo];
C=[1 0];
D=[0; 0];



%variables to define the control
xl=.1*c; 
T=1; %saturator limit
alpha=.5; %discount factor
%slopes for the linearized region
k1=(c-xl)/(c*xl); 
k2=sqrt(2*c*alpha*xl-alpha*xl^2)/(alpha*w*c*xl);
x2_bound=2*bo/w;
x1Tol = 2.6*10^-12;
x2Tol = .00001;

%initial condition
Xo=[-5*c,5*10^4];
trun=pi/w;
x2stop=-Xo(2);
step_sz=.0000006;

trun = ceil(trun/step_sz)*step_sz;

%%I want to plot the switching curve so run the function
%%to run a function to get x1, x2 for switching curves
[curves_ptosx1, curves_ptosx2, curves_optx1, curves_optx2]=switching_curves_comp_func(c, w, bo, alpha, xl, Xo);
x1=curves_ptosx1;


% plot(curves_optx1, curves_optx2)
% grid on

for i=1:length(x1)
    if( abs(x1(i)) < 2*c & abs(x1(i)) > xl)

        Fptos= sign( x1(i) ) *( w*sqrt(alpha*2*c*abs(x1(i)) -alpha*x1(i)^2) -1/k2);
        x2_upper(i)=-(-1/k2 + Fptos);
        x2_lower(i)= -(1/k2 + Fptos);
     elseif(abs(x1(i)) <xl)
         Fptos=(k1/k2)*x1(i);
         x2_upper(i)=-(-1/k2 + Fptos);
         x2_lower(i)=-(1/k2 + Fptos);
    end
end




u=-1;
Xo=[-5*c, 6.5*10^4];

% show x1 axis crossing
trun2 = 5*pi/w;
trun2 = ceil(trun2/step_sz)*step_sz;
sim('simulink_models/rotate_piw')
x1_rotate=xout_rotate(:,1);
x2_rotate=xout_rotate(:,2);
a=Xo;
[~, k]=min(abs( abs(curves_optx1+6.4*c)));
[~, j]=min(abs(x2_rotate));


Xo=[curves_optx1(k), curves_optx2(k)];
sim('simulink_models/opt_flex');
x1opt1=xout_opt(:,1); %save the output to individual vectors
x2opt1=xout_opt(:,2);



u=0;
sim('simulink_models/rotate_piw')  %%%now run from same spot on curve with no input to illustrate 2c extraction.
x1_rotate2=xout_rotate(:,1);
x2_rotate2=xout_rotate(:,2);
n=length(x1_rotate);



b=[x1_rotate(n), x2_rotate(n)];


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% For Normal Figures
height=1.75/1.618; % width/golden ratio
width=1;
% For Wide Figures
% height=1.0/1.618; % width/golden ratio
% width=2;
xpos=2249;
ypos=569;
scale=350; % 3.13 inches
F1=figure(1); % Create Figure
axes('FontName','Times New Roman') % Set axis font style
box('on'); % Define box around whole figure
set(gcf,'Position',[xpos ypos scale*width scale*height]) % Set figure format

hold on;

% PLOT SWITCHING CURVES AND PTOS CURVE
% hp3=plot(curves_ptosx1, curves_ptosx2, 'LineWidth', 2);
hp4=plot(curves_optx1, curves_optx2, 'r', 'LineWidth', 1.5 );
hp5=plot(x1, x2_upper, 'k', 'LineWidth', 1.3);
hp6=plot(x1, x2_lower, 'k', 'LineWidth', 1.3);



hp0=plot(x1opt1, x2opt1, 'b', 'LineWidth', 2); %%u=time-optimal
% hp0.Color=[217, 83, 25]/255;

hp1=plot(x1_rotate2, x2_rotate2, 'g', 'LineWidth', 2); %%zero input response

% x1 axis crossing
[~, k]=min(abs(x2_rotate));
hp2=plot(x1_rotate(1:k), x2_rotate(1:k), 'LineWidth', 2);
hp2.Color=[237, 177, 32]/255;




dotthick=12;
p1=plot(x1_rotate(j), x2_rotate(j), '.k', 'MarkerSize', dotthick);
p2=plot(a(1), a(2), '.k', 'MarkerSize', dotthick);
% p3=plot(b(1), b(2), '.k', 'MarkerSize', dotthick)
p4=plot(Xo(1), Xo(2), '.k', 'MarkerSize', dotthick);
p5=plot(x1opt1(n), x2opt1(n), '.k', 'MarkerSize', dotthick);
p6=plot(x1_rotate2(n), x2_rotate2(n), '.k', 'MarkerSize', dotthick);

grid on

%%%%%% build the axes
ax=gca;
set(ax, 'XTick', [-8*c:2*c:9*c]);
% set(ax, 'XTick', [-3*pi,-2*pi,-pi,0,pi,2*pi,3*pi]);
set(ax, 'YTick', [-8*bo/w:2*bo/w:9*bo/w]);
set(ax, 'YTickLabel', [])


yticks=get(ax, 'ytick');
xticks=get(ax, 'xtick');
% set(ax, 'XTickLabel', {'-6c','-5c','-4c','-3c','-2c', '-c','0','c','2c','3c','4c','5c','6c'}, 'FontSize', 36);
set(ax, 'XTickLabel', [])

my_yticks={'$\frac{-8b_o}{w}$','$\frac{-6b_o}{w}$','$\frac{-4b_o}{w}$','$\frac{-2b_o}{w}$','$0$','$\frac{2b_o}{w}$', '$\frac{4b_o}{w}$', '$\frac{6b_o}{w}$','$\frac{8b_o}{w}$'};
my_xticks={'$-8c$','$-6c$','$-4c$','$-2c$','$0$','$2c$','$4c$','$6c$','$8c$'};
axs=axis;
HorizontalOffset=-8.1*c;
VertOffset=.95*5*bo/w;

for i=1:length(my_yticks)
  text(HorizontalOffset, yticks(i),my_yticks(i),'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize', 12)   

end

for i=1:length(my_xticks)
  text(xticks(i)+2, axs(3)-VertOffset, my_xticks(i),'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize',10);   

end

text(.15, .4, '$\mathcal{U}^+$', 'units', 'normalized', 'interpreter', 'latex', 'FontSize', 14)
text(.9, .9, '$\mathcal{U}^-$', 'units', 'normalized', 'interpreter', 'latex', 'FontSize', 14)

text(.13, .9, 'A', 'units', 'normalized', 'interpreter', 'latex', 'FontSize', 12)

text(.045, .57, 'C', 'units', 'normalized', 'interpreter', 'latex', 'FontSize', 12)
text(.77, .4, 'D', 'units', 'normalized', 'interpreter', 'latex', 'FontSize', 12)
text(.87, .4, 'E', 'units', 'normalized', 'interpreter', 'latex', 'FontSize', 12)
text(.95, .51, 'F', 'units', 'normalized', 'interpreter', 'latex', 'FontSize', 12)
% text(.68, .1, 'B', 'units', 'normalized', 'interpreter', 'latex', 'FontSize', 12)


xlim([-8*c, 8*c])
ylim([-8.5*bo/w, 9*bo/w])

% Create xlabel
hxlab=xlabel('$x_1$','FontSize',18,'FontName','Times New Roman','FontAngle','italic');

% Create ylabel
hylab=ylabel('$x_2$','FontSize',18,'FontName','Times New Roman','FontAngle','italic','rot',0);
set(hylab, 'Units', 'Normalized', 'Position', [-.15, 0.5, 0]);
set(hxlab, 'Units', 'Normalized', 'Position', [.5, -0.045, 0]);
set(hxlab, 'interpreter', 'latex');
set(hylab, 'interpreter', 'latex');

axpos = get(gca,'pos');
set(gca,'pos',[axpos(1)+.051 axpos(2) axpos(3) axpos(4)])
leg{1}=['2c extraction'];
% leg{2}=['Zero input response'];
% leg{3}=['Time to curve'];
h=legend([hp0, hp1, hp2, hp4, hp5], '$u=f_{to}$', 'zero input response', '$x_1$-axis crossing', 'time-optimal switching curve', 'region $\mathcal{T}$ boundary');
h.Location='southwest';
h.Position = [0.1895 0.1224 0.5955 0.2113];
h.Interpreter='latex';
% set(h,'FontSize',25, 'FontWeight', 'bold');
% % 'interpreter','latex'



% text(.2, .95, '$\mathcal{U}^-$', 'Units', 'Normalized', 'interpreter', 'latex', 'FontSize', 12)
% text(.8, .05, '$\mathcal{U}^+$', 'Units', 'Normalized', 'interpreter', 'latex', 'FontSize', 12)
%% 
% set(gcf, 'Color', 'white'); % white bckgr
% saveas(gcf, '/home/arnold/paper-trunk/plots/finite_timeeps3.eps', 'epsc')


