%% define these parameters so the simulink model will run
%model

clear, clc
bo = 1.8276*10^7;
w=2*pi*3.175*10^2;
c=bo/w^2;
zeta=0;

%make the state space matrices
A=[0 1;-(w)^2 0;]; 
B=[0; bo];
C=[1 0];
D=[0; 0];


%variables to define the control
xl=.3*c; 
T=1; %saturator limit
alpha=.8; %discount factor
%slopes for the linearized region
k1=(c-xl)/(c*xl); 
k2=sqrt(2*c*alpha*xl-alpha*xl^2)/(alpha*w*c*xl);
x2_bound=10*bo/w;


%initial condition
Xo=[2*c, 0];


% I want to plot the switching curve so run the function
%%to run a function to get x1, x2 for switching curves
[curves_ptosx1, curves_ptosx2, curves_optx1, curves_optx2]=switching_curves_comp_func(c, w, bo, alpha, xl, Xo);
x1=curves_ptosx1;
x2=curves_ptosx2;


% create saturator bounds
for i=1:length(x1)
    if( abs(x1(i)) <= 2*c & abs(x1(i)) > xl)
        Fptos= sign( x1(i) ) *( w*sqrt(2*c*alpha*abs(x1(i)) -alpha*x1(i)^2) -1/k2);
        x2_upper(i)=-(-1/k2 + real(Fptos));
        x2_lower(i)= -(1/k2 + real(Fptos));
    elseif(abs(x1(i)) <xl)
        Fptos=(k1/k2)*x1(i);
        x2_upper(i)=-(-1/k2 + real(Fptos));
        x2_lower(i)=-(1/k2 + real(Fptos));
    end

end


% Setup figure size
clf;
height=1.65/1.618;
width=1.4;
xpos=997;
ypos=546;
scale=350;

f1=figure(1);

axes('FontName','Times New Roman') % Set axis font style
box('on'); % Define box around whole figure
set(gcf,'Position',[xpos ypos scale*width scale*height]) % Set figure format
hold on
curves_optx2(1)=0; curves_optx2(9185)=0; curves_optx2(27553)=0; curves_optx2(36737)=0;

% plot(curves_ptosx1, curves_ptosx2, curves_optx1, curves_optx2, x1, x2_upper, x1, x2_lower)
plot_ptoscurve = plot(curves_ptosx1, curves_ptosx2, 'k');
plot_upper    = plot(x1, x2_upper-100, 'k');
plot_lower    = plot(x1, x2_lower, 'k');
plot_optleft  = plot(curves_optx1(1:9185), curves_optx2(1:9185), 'r', 'LineWidth', 2);
plot_optright = plot(curves_optx1(27553:36737), curves_optx2(27553:36737), 'r', 'LineWidth', 2);

%%%%%%%%%%%%%%%%%%%%%%%
m=length(x1);
[a, j]=min(abs(x1));  %% x1 = 0

[a, k]=min(abs( abs(x1(1:j))-c)); %% x1=c
[a, l]=min(abs( abs(x1(j:length(x1))) -c));
[a, n]=min(abs( abs(x1(j:length(x1))) -xl));
n=n+j;
l=l+j;


p4=plot(x1(j:n), x2_upper(j:n), 'm', 'linewidth', 1.5); %%AB
p5=plot(x1(n:m), x2_upper(n:m), 'c', 'linewidth', 1.5); %%BC
p6=plot(x1(j:n), x2_lower(j:n), 'k', 'linewidth', 1.5); %%DE
p7=plot(x1(n:l), x2_lower(n:l), 'linewidth', 1.5); %% EF
p7.Color=[.87, .49, 0];
x2_lower(m) = 0;
p8=plot(x1(l:m), x2_lower(l:m), 'b', 'linewidth', 1.5); %%FG

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
m=length(x1);
[a, j]=min(abs(x1));  %% x1 = 0

[a, k]=min(abs( abs(x1(1:j))-c)); %% x1=c
[a, l]=min(abs( abs(x1(j:length(x1))) -c));
[a, n]=min(abs( abs(x1(j:length(x1))) -xl));
n=n+j;
l=l+j;
p=plotshaded(x1(1:k), [x2_upper(1:k); x2_lower(1:k)], 'k', .20);
plotshaded(x1(k:l), [x2_upper(k:l); x2_lower(k:l)], 'k', .50);
plotshaded(x1(l:m), [x2_upper(l:m); x2_lower(l:m)], 'k', .2);

xll=plot([xl, xl], [-2*bo/w, 2*bo/w], '--g', 'LineWidth',2);
xlll=plot([-xl, -xl], [-2*bo/w, 2*bo/w], '--g', 'LineWidth', 2);
xcpl=plot([c, c], [-2*bo/w, 2*bo/w], '--b', 'LineWidth', 2);
xcp=plot([-c, -c], [-2*bo/w, 2*bo/w], '--b', 'LineWidth', 2);

ax=gca;
set(ax, 'XTick', [-4*c:c:4*c]);
set(ax, 'YTick', [-bo/w:bo/w:bo/w]);


xlim([-4*c, 4*c]);
ylim([1.2*min(curves_optx2), 1.2*max(curves_optx2)]);
set(ax, 'YTickLabel', [])
set(ax, 'XTickLabel', [])

yticks=get(ax, 'ytick');
xticks=get(ax, 'xtick');

my_yticks={'$\frac{-b_o}{w}$','$0$','$\frac{b_o}{w}$'};
my_xticks={'$-4c$','$-3c$','$-2c$', '$-c$','$0$','$c$','$2c$','$3c$','$4c$'};
axs=axis;
HorizontalOffset=.1;
VertOffset=1200;

for i=1:length(yticks)
  text(axs(1)-HorizontalOffset, yticks(i),my_yticks(i),'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize', 16);   

end

for i=1:length(xticks)
  text(xticks(i)+.8, axs(3)-VertOffset, my_xticks(i),'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize', 12);   

end

% Create ylabel
hylab=ylabel('$x_2$','FontSize',16,'FontName','Times New Roman','FontAngle','italic','rot',0);
set(hylab, 'Units', 'Normalized', 'Position', [-0.095, 0.5, 0]);

hxlab=xlabel('$x_1$','FontSize',16,'FontName','Times New Roman','FontAngle','italic');
set(hxlab, 'Units', 'Normalized', 'Position', [.45, -0.04, 0]);
set(hxlab, 'interpreter', 'latex');
set(hylab, 'interpreter', 'latex');

h_plus=text(1,1, '$\mathcal{U^+}$', 'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize', 16);
h_plus.Units='Normalized';
h_plus.Position=[.2,.2];
h_min=text(.90,.85, '$\mathcal{U^-}$', 'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize', 16, 'Units', 'Normalized');
h_B=text(.44,.6, '$\mathcal{B}$', 'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize', 12, 'Units', 'Normalized');

h_T=text(.36,.6, '$\mathcal{T}$', 'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize', 12, 'Units', 'Normalized');
h_T2=text(.7,.4, '$\mathcal{T}$', 'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize', 12, 'Units', 'Normalized');
h_xl=text(.59,.04, '$x_{\ell}$', 'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize', 10, 'Units', 'Normalized');
h_xl=text(.66,.04, '$c$', 'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize', 10, 'Units', 'Normalized');

%%%%%%%%%%%%%%%%%%%%5
text(.48, 0.69, 'A', 'Units', 'Normalized', 'FontSize', 14)
text(.54, 0.57, 'B', 'Units', 'Normalized', 'FontSize', 14)
text(.63, 0.48, 'H', 'Units', 'Normalized', 'FontSize', 14)
text(.63, 0.1, 'F', 'Units', 'Normalized', 'FontSize', 14)
text(.47, 0.37, 'D', 'Units', 'Normalized', 'FontSize', 14)
text(.54, 0.260, 'E', 'Units', 'Normalized', 'FontSize', 14)

text(.76, 0.5, 'G', 'Units', 'Normalized', 'FontSize', 14)
text(.76, .8, 'C', 'Units', 'Normalized', 'FontSize', 14)
%%%%%%%%%%%%%%%%%%%%

grid on



% set(gcf, 'Color', 'white'); % white bckgr
% saveas(gcf, '/home/arnold/Desktop/AFM/paper-trunk/paper/plots/regions_BTL2.eps', 'epsc')
