%%%%%definition
clear,clc

bo = 1.8276*10^7;
w=2*pi*3.175*10^2;
c=bo/w^2;
zeta=0;

%make the state space matrices
A=[0 1;-(w)^2 0;]; 
B=[0; bo];
C=[1 0];
D=[0; 0];


%variables to define the control
xl=.21*c; 
T=1; %saturator limit
alpha=0.7; %discount factor
%slopes for the linearized region
k1=(c-xl)/(c*xl); 
k2=sqrt(2*c*alpha*xl-alpha*xl^2)/(alpha*w*c*xl);
x2_bound=2*bo/w;


%initial condition
Xo=[3.0*c,0];


step_sz=1e-7;
trun=3.8e-3;
trun = ceil(trun/step_sz)*step_sz;
TOL=.00001;
% I want to plot the switching curve so run the function
%%to run a function to get x1, x2 for switching curves
[curves_ptosx1, curves_ptosx2, curves_optx1, curves_optx2]=switching_curves_comp_func(c, w, bo, alpha, xl, Xo);
x1=curves_ptosx1;


for i=1:length(x1)
    if( abs(x1(i)) < 2*c & abs(x1(i)) > xl)

        Fptos= sign( x1(i) ) *( w*sqrt(alpha*2*c*abs(x1(i)) -alpha*x1(i)^2) -1/k2);
        x2_upper(i)=-(-1/k2 + Fptos);
        x2_lower(i)= -(1/k2 + Fptos);
     elseif(abs(x1(i)) <xl)
         Fptos=(k1/k2)*x1(i);
         x2_upper(i)=-(-1/k2 + Fptos);
         x2_lower(i)=-(1/k2 + Fptos);
    end
end


%  %%%MAKE SURE GAUSSIAN IS NOT SELECTED IN MODEL!!!!!!!!

wbar = w;
bobar = bo;
cbar = c;

x2Tol = .001*bo/w;
x1Tol = .001*c;


sim('simulink_models/compare_opt_PTOS');

x1known  = x1ptos;
x2_known = x2ptos;
u_known  = u_ptos;
t_known  = tout_ptos;

wbar = 0.99*w;
bobar = 1.01*bo;
cbar = bobar/wbar^2;

sim('simulink_models/compare_opt_PTOS');



%
x2known=x2_known;
height=1.3/1.618; % width/golden ratio
width=.8;
% Figure size
xpos=-450;
ypos=500;
scale=350; % 3.13 inches
figure(1); % Create Figure
axes('FontName','Times New Roman') % Set axis font style
box('on'); % Define box around whole figure
set(gcf,'Position',[xpos ypos scale*width scale*height]) % Set figure format


hold on;
lthick=1.3;
h_optcurve=plot(curves_optx1, curves_optx2, 'r', 'LineWidth', lthick);
h_uppersat=plot(x1, x2_upper, 'k', 'LineWidth', lthick);
h_lowersat=plot(x1, x2_lower, 'k', 'LineWidth', lthick);


h_known=plot(x1known, x2known, 'g', 'LineWidth', lthick);
h_PTOS=plot(x1ptos, x2ptos, '--b', 'LineWidth', lthick);

grid on

%%
%%%%%% build the axes
ax=gca;
set(ax, 'XTick', [-4*c:2*c:4*c]);
% set(ax, 'XTick', [-3*pi,-2*pi,-pi,0,pi,2*pi,3*pi]);
set(ax, 'YTick', [-2*bo/w:2*bo/w:4*bo/w]);
set(ax, 'YTickLabel', [])


yticks=get(ax, 'ytick');
xticks=get(ax, 'xtick');
% set(ax, 'XTickLabel', {'-4c','-3c','-2c', '-c','0','c','2c','3c','4c','5c','6c'}, 'FontSize', 36);
set(ax, 'XTickLabel', [])
xlim([-4*c, 4*c])
ylim([-2.2*bo/w, 2.5*bo/w])

my_yticks={'$\frac{-2b_o}{w}$','$0$','$\frac{2b_o}{w}$', '$\frac{4b_o}{w}$'};
my_xticks={'$-4c$','$-2c$','$0$','$2c$','$4c$'};
axs=axis;
HorizontalOffset=-1;
VertOffset=2900;

for i=1:length(my_yticks)
  text(axs(1)+HorizontalOffset, yticks(i),my_yticks(i),'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize', 14)   

end

for i=1:length(my_xticks)
  text(xticks(i)+2, axs(3)-VertOffset, my_xticks(i),'HorizontalAlignment','Right','interpreter', 'latex', 'FontSize',14);   

end
legend()

text(.15, .2, '$\mathcal{U}^+$', 'units', 'normalized', 'interpreter', 'latex', 'FontSize', 14);
text(.8, .6, '$\mathcal{U}^-$', 'units', 'normalized', 'interpreter', 'latex', 'FontSize', 14);
text(-.15, .45, '$x_2$', 'units', 'normalized', 'interpreter', 'latex', 'FontSize', 14);
text(.45, -.1, '$x_1$', 'units', 'normalized', 'interpreter', 'latex', 'FontSize', 14);


% hleg1=legend([h_optcurve, h_uppersat, h_PTOS, h_OPT], '$f_{to}$', 'saturation boundary', 'PTOS trajectory', 'Time Optimal Trajectory');
hleg1=legend([h_optcurve, h_uppersat,h_known h_PTOS], '$-f_{to}$', 'saturation boundary','PTOS trajectory: perfect model', 'PTOS trajectory: imperfect model');

set(hleg1,  'FontSize', 7);
set(hleg1,'Interpreter','latex')
set(hleg1,'Position',[0.1460 0.7113 0.7072 0.1854])
set(hleg1,'box','on')
%uistack(hleg1, 'top')

%%%%% NOW PLOT CONTRON HISTORY
%
figure(2);

height=1.3/1.618; % width/golden ratio
width=.62;
xpos=-450;
ypos=500;
scale=350; % 3.13 inches
% figure(1); % Create Figure
axes('FontName','Times New Roman') % Set axis font style
box('on'); % Define box around whole figure
set(gcf,'Position',[xpos ypos scale*width scale*height]) % Set figure format
hold on;

h_known=plot(t_known*1000, u_known, 'g', 'LineWidth', lthick); %%prfect modl
h_PTOS=plot(tout_ptos*1000, u_ptos, '--b', 'LineWidth', lthick); %%imperfect model
% 
hleg2=legend([h_known h_PTOS], 'perfect model', 'imperfect model');
hleg2.Position=[0.2316 0.7826 0.6360 0.1124];
hleg2.FontSize = 7;
grid on;
% title('Control history for the PTOS solution');
xlabel('t [ms]', 'interpreter', 'latex', 'FontSize', 14);
ylabel('u(t)', 'interpreter', 'latex', 'FontSize', 14);
ylim([-1.1 1.6])
xlim([0, 3.5])

